#!/usr/bin/php
<?php

use Console\SendMail;
use Logger\Log;
use Services\Helpers;
use Wildix\Core\Container;
use Wildix\Core\Notification;

require_once('/var/www/init.php');

const LOG_PATTERN = 'Send email: type::%s to::%s, template::%s, lang::%s, instant::%s';

$lang = 'english';

function showHelp() {

    echo('Send email script.' . PHP_EOL);
	echo ('Usage: /usr/sbin/sendemail.php --body="Some text" --to="email@address"' . PHP_EOL . PHP_EOL);
	echo ('options:' . PHP_EOL
	. '   --type        Type of the mail template.' . PHP_EOL
	. '   --body        Mail body(Has more priority then body64).' . PHP_EOL
	. '   --body64      Mail body encoded with base64.' . PHP_EOL
	. '   --to          Recipient email.' . PHP_EOL
	. '   --from        Sender email.' . PHP_EOL
	. '   --replyto     Reply to email.' . PHP_EOL
	. '   --cc          Carbon-copy (CC) address.' . PHP_EOL
	. '   --bcc         Blind carbon-copy (BCC) address.' . PHP_EOL
	. '   --attach      Attach a file to the message.' . PHP_EOL
	. '   --template    Custom template name. By default: "default"' . PHP_EOL
	. '   --subject     Email subject(Has more priority then subject64).' . PHP_EOL
	. '   --subject64   Email subject encoded with base64.' . PHP_EOL
	. '   --asrLanguage If type === "voicemail" you can provide this param for voicemail language. (default English) .' . PHP_EOL
	. '   --asrFile     If type === "voicemail" you can provide this param for a separate file that will be sent to the recognition .' . PHP_EOL
	. '   --transcript  Transcript voicemail or not. Values: "yes" or "no". By default: "yes".' . PHP_EOL
    . '   --language    Message language (default "en").' . PHP_EOL
    . 'required options for messages with type="missedCall"' . PHP_EOL
    . '   --name        Caller name.' . PHP_EOL
    . '   --name64      Caller name encoded with base64.' . PHP_EOL
    . '   --number      Caller number.' . PHP_EOL
    . '   --instant     Send email instantly.' . PHP_EOL
    . '   --timestamp   Call timestamp (in seconds).' . PHP_EOL);

	// Exit after show help
    die(1);
}

// get parameters
$arrayOfOptions = array(
    'type:', 'body:', 'body64:', 'attach:', 'to:', 'from:', 'replyto:', 'cc:', 'bcc:', 'subject:', 'subject64:', 'template:', 'asrLanguage:', 'language:',
    'name:', 'name64:', 'number:', 'timestamp:', 'asrFile:', 'transcript:', 'instant'
);

$params = getopt('', $arrayOfOptions);

// check parameters
if ((empty($params['type']) && empty($params['body']) && empty($params['body64'])) || empty($params['to'])) {
    showHelp();
}

if (!empty($params['language'])) {
    $lang = \Language::getInstance()->getLanguageNameByCode(strtolower(trim($params['language'])));
    $_SESSION['language'] = empty($lang) ? 'english' : $lang;
}

$instant = isset($params['instant']);

$message = sprintf(LOG_PATTERN, $params['type'], $params['to'], $params['template'], $lang, $instant ? 'true' : 'false');
Container::get(Log::class)->info(__LINE__, $message);

if ($instant) {
    try {
        Notification::sendEmail($params);
    } catch (Exception $e) {
        Container::get(Log::class)->error(__LINE__, sprintf('Error while sending email. Error: %s', $e->getMessage()));
    }
} else {
    Helpers::addTask(SendMail::NAME, $params);
}

die(0);
