#!/usr/bin/php
<?php

use Logger\Log;
use Wildix\Colleagues\Colleagues;
use Wildix\Core\Container;
use Wildix\Integration\XBees\Service\XbeesService;
use Wildix\Services\Fs;
use Wildix\Services\SpeechToText;

require_once '/var/www/init.php';

function displayHelp() {
    echo 'Usage: /usr/sbin/sendxbeesmessage.php --owner 201 --id x-bees-channel-id --asrLanguage en --asrFile /tmp/2023.05.10-10.54.57-201-201[pbx]-02d44-0.wav' . PHP_EOL . PHP_EOL;
    echo 'options:' . PHP_EOL
        . '   --id          Id of the x-bees channel.' . PHP_EOL
        . '   --owner       Owner of the message.' . PHP_EOL
        . '   --type        type of the message (only: transcribe).' . PHP_EOL
        . '   --asrLanguage Users language.' . PHP_EOL
        . '   --asrFile     full path to the file for ASR.' . PHP_EOL
        . '   --body64      Message text encoded with base64.' . PHP_EOL
        . '   --attach      Attach a file to the message.' . PHP_EOL;

    exit();
}

$optionsList = [
    'id:',
    'owner:',
    'type:',
    'asrLanguage:',
    'asrFile:',
    'body64:',
    'attach:',
];


$options = getopt('', $optionsList);
if (empty($options['id']) || empty($options['owner']) || empty($options['asrLanguage']) || empty($options['asrFile'])) {
    displayHelp();
}

try {
    /** @var SpeechToText $sttService */
    $sttService = Container::get(SpeechToText::class);
    $text = $sttService->getTextFromVoiceMail($options['asrFile'], $options['asrLanguage']);
    if ($text === false) {
        throw new Exception(sprintf("Can not recognise audio file: %s", $options['asrFile']));
    }

    if (empty(trim($text))) {
        exit('Empty audio file or transcription.');
    }

    /** @var Colleagues $userRepository */
    $userRepository = Container::get(Colleagues::class);
    $user = $userRepository->getUserByExtension($options['owner']);

    /** @var Fs $fsService */
    $fsService = Container::get(Fs::class);
    $uploadedFileInfo = $fsService->uploadFileFromUser($user, $options['asrFile']);

    /** @var XbeesService $xbeesService */
    $xbeesService = Container::get(XbeesService::class);
    $xbeesService->postMessage(
        $options['id'],
        $options['owner'],
        [
            'message'     => $text,
            'attachments' => [
                [
                    "mime"      => $uploadedFileInfo['type'] ?? '',
                    "size"      => $uploadedFileInfo['size'] ?? '',
                    "name"      => $uploadedFileInfo['name'] ?? '',
                    "fsId"      => $uploadedFileInfo['id'] ?? '',
                    "thumbnail" => $uploadedFileInfo['thumbnail'] ?? '',
                ],
            ],
        ]
    );
} catch (Throwable $exception) {
    /** @var Log $logger */
    $logger = Container::get(Log::class);
    $errorMessage = sprintf('Failed to send message to x-bees channel: %s', $exception->getMessage());
    $logger->error(__LINE__, $errorMessage);

    exit($errorMessage);
}

exit();
