<?php

namespace Wildix\Normalizer;

/**
 * Class PhoneNumberNormalizer
 */
class PhoneNumberNormalizer {

    public function __construct(private ?string $internationalPrefix = '', private ?string $nationalPrefix = '', private ?string $countryCode = '') {
    }

    /**
     * Normalize phone number
     *
     * @param string $phoneNumber Value for normalize.
     * @param integer $numberLength Length number for normalize.
     * @param boolean $ignoreStartsFromLetter Is TRUE then numbers starts from letter will be skipped.
     *
     * @return string
     */
    public function normalize($phoneNumber, $numberLength = 6, $ignoreStartsFromLetter = false) {
        if ($ignoreStartsFromLetter && !ctype_digit(mb_substr($phoneNumber, 0, 1))) {
            return $phoneNumber;
        }

        $cidLen = mb_strlen((string)$phoneNumber);

        if ($cidLen <= $numberLength || $phoneNumber[0] == '+') {
            return $phoneNumber;
        }

        $internationalPrefLen = mb_strlen($this->internationalPrefix);
        $nationalPrefLen = mb_strlen($this->nationalPrefix);
        $firstChar = mb_substr($phoneNumber, 0, 1);

        if ($internationalPrefLen > 0 && mb_substr($phoneNumber, 0, $internationalPrefLen) == $this->internationalPrefix) {
            return '+' . mb_substr($phoneNumber, $internationalPrefLen);
        }

        if ($nationalPrefLen > 0 && mb_substr($phoneNumber, 0, $nationalPrefLen) == $this->nationalPrefix) {
            $result = !empty($this->countryCode) ? '+' . $this->countryCode : '';
            $result .= ($this->countryCode == '39') ? $phoneNumber : mb_substr($phoneNumber, $nationalPrefLen);

            return $result;
        }

        if ($this->countryCode == '39' && ($cidLen == 10 || in_array($firstChar, ['8', '7', '4', '3', '1']))) {
            // '8' -- Special rate numbers
            // '7' -- Internet service numbers
            // '4' -- Internal phone net service numbers
            // '3' -- Mobile phones
            // '1' -- Service and emergency numbers
            return '+39' . $phoneNumber;
        }

        if ($this->countryCode == '380' && mb_substr($phoneNumber, 0, 2) == '80') {
            return '+3' . $phoneNumber;
        }

        if ($this->countryCode == '39') {
            return '+' . $this->countryCode . $this->nationalPrefix . $phoneNumber;
        }

        return !empty($this->countryCode) ? '+' . $this->countryCode . $phoneNumber : $phoneNumber;
    }
}
