BEGIN TRANSACTION;
CREATE TABLE IF NOT EXISTS `cti_phonebooks` (
	`rid` INTEGER PRIMARY KEY AUTOINCREMENT,
	`name` varchar(255),
	`type` int,
	`owner_id` int,
	`hash` varchar(255) default '',
	`sync_set` int(1) default 0,
	`sync_interval` int(2) default 0,
	`sync_params` text default ''
);
CREATE INDEX IF NOT EXISTS `idx_cti_phonebooks_name` ON `cti_phonebooks` (`name`);
CREATE INDEX IF NOT EXISTS `idx_cti_phonebooks_type` ON `cti_phonebooks` (`type`);
CREATE INDEX IF NOT EXISTS `idx_cti_phonebooks_owner_id` ON `cti_phonebooks` (`owner_id`);

CREATE TABLE IF NOT EXISTS `cti_contacts` (
	`rid` INTEGER PRIMARY KEY AUTOINCREMENT,
	`source_id` varchar(255) default '' not null,
	`owner_id` varchar(255) default '' not null,
	`username` varchar(255) default '' not null,
	`email` varchar(255) default '' not null,
	`extension` varchar(255) default '' not null,
	`phone` varchar(255) default '' not null,
	`office` varchar(255) default '' not null,
	`home` varchar(255) default '' not null,
	`home_mobile` varchar(255) default '' not null,
	`fax` varchar(255) default '' not null,
	`mobile` varchar(255) default '' not null,
	`organization` varchar(255) default '' not null,
	`image_url` varchar(512) default '' not null,
	`shortcut` varchar(255) default '' not null,
	`phonebook_id` int,
	`group_id` varchar(255) default '' not null,
	`user_class` varchar(255) default '' not null,
	`ringtone` varchar(255) default '' not null,
	`note` text,
	`address` varchar(255) default '' not null,
	`vat_id` varchar(32) default '' not null,
	`name_prefix` varchar(32) default '' not null,
	`user_passport_type` varchar(128) default '' not null,
	`user_passport_id` varchar(128) default '' not null,
	`pin` int,
	`credit` int,
	`hash` varchar(255) default '' not null,
	`country` char(2) default 'it' not null,
	`date_birth` date,
	`born_in` varchar(255) default '' not null,
	`postal_code` varchar(20),
	`city` varchar (255) default '' not null,
	`province` varchar (255) default '' not null,
	`license_plate` varchar (16) default '' not null,
	`document_released_on` date,
	`document_from` varchar (255) default '' not null,
	`last_update` DATETIME DEFAULT ''
);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_username` ON `cti_contacts` (`username`);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_phone` ON `cti_contacts` (`phone`);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_fax` ON `cti_contacts` (`fax`);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_mobile` ON `cti_contacts` (`mobile`);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_extension` ON `cti_contacts` (`extension`);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_home` ON `cti_contacts` (`home`);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_home_mobile` ON `cti_contacts` (`home_mobile`);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_office` ON `cti_contacts` (`office`);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_shortcut` ON `cti_contacts` (`shortcut`);
CREATE INDEX IF NOT EXISTS `idx_cti_contacts_pg_id` ON `cti_contacts` (`phonebook_id`, `group_id`);
CREATE TRIGGER IF NOT EXISTS `add_date` AFTER INSERT ON `cti_contacts`
    BEGIN
        UPDATE `cti_contacts` SET last_update = datetime('now', 'localtime') WHERE rid = new.rid;
    END;
CREATE TRIGGER IF NOT EXISTS `update_date` AFTER UPDATE ON `cti_contacts`
    BEGIN
        UPDATE `cti_contacts` SET last_update = datetime('now', 'localtime') WHERE rid = new.rid;
    END;

CREATE TABLE IF NOT EXISTS `cdr_periods` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `uid` INTEGER NOT NULL,
    `value` VARCHAR(255) NOT NULL,
    `sla_value` INTEGER DEFAULT 0 NOT NULL,
    `miss_call_sec_value` INTEGER DEFAULT 0 NOT NULL
);

CREATE TABLE IF NOT EXISTS `cdr_filters` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `uid` INTEGER NOT NULL,
    `name` VARCHAR(64) NOT NULL,
    `description` VARCHAR(255),
    `filter` TEXT,
    `shared` CHAR(1)
);

CREATE VIRTUAL TABLE IF NOT EXISTS cti_contacts_fts4 USING fts4(content="cti_contacts", username, email, organization);

CREATE TRIGGER IF NOT EXISTS cti_contacts_fts4_bu BEFORE UPDATE ON cti_contacts BEGIN
  DELETE FROM cti_contacts_fts4 WHERE docid=old.rowid;
END;
CREATE TRIGGER IF NOT EXISTS cti_contacts_fts4_bd BEFORE DELETE ON cti_contacts BEGIN
  DELETE FROM cti_contacts_fts4 WHERE docid=old.rowid;
END;

CREATE TRIGGER IF NOT EXISTS cti_contacts_fts4_au AFTER UPDATE ON cti_contacts BEGIN
  INSERT INTO cti_contacts_fts4(docid, username, email, organization) VALUES(new.rowid, new.username, new.email, new.organization);
END;
CREATE TRIGGER IF NOT EXISTS cti_contacts_fts4_ai AFTER INSERT ON cti_contacts BEGIN
  INSERT INTO cti_contacts_fts4(docid, username, email, organization) VALUES(new.rowid, new.username, new.email, new.organization);
END;

COMMIT;
