BEGIN TRANSACTION;
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `cac` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `cac_name` varchar(40) UNIQUE,
    `cac_networks` varchar(255),
    `cac_limit` smallint(3)
);
CREATE INDEX IF NOT EXISTS `idx__cac_cac_name` on `cac`(`cac_name`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `call_groups` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `call_groupname` varchar(40) UNIQUE,
    `queue_parameters` text
);
CREATE INDEX IF NOT EXISTS `idx__call_groups_call_groupname` on `call_groups`(`call_groupname`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `call_groups_members` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `call_group_id` int(11),
    `group_member` varchar(20),
    `group_membername` varchar(40),
    `penalty` int(11)
);
CREATE INDEX IF NOT EXISTS `idx__call_groups_members_call_group_id` on `call_groups_members`(`call_group_id`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `dialplan_links`(
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    object_from_type INTEGER,
    object_from_id INTEGER,
    object_to_type INTEGER,
    object_to_id VARCHAR(80)
);
CREATE INDEX IF NOT EXISTS `idx_dialplan_links_object_to_type_object_to_id` ON `dialplan_links` (`object_to_type`, `object_to_id`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `dialplan_rulenames` (
    `id`  INTEGER PRIMARY KEY AUTOINCREMENT,
    `rulename` varchar(127) UNIQUE,
    `ruledescription` varchar(127),
    `subrule_id` int(11)
);
CREATE INDEX IF NOT EXISTS `dialplan_rulenames__idx_rulename` on `dialplan_rulenames`(`rulename`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `dialplan_rules` (
    `id`  INTEGER PRIMARY KEY AUTOINCREMENT,
    `rule_id` int(11),
    `number` varchar(15),
    `exmatch` int(1),
    `priority` int(3),
    `application` varchar(40),
    `parameters` varchar(255),
    `dialplanappname` varchar(40),
    `comment` varchar(255) NOT NULL default ''
);
CREATE INDEX IF NOT EXISTS `dialplan_rules__idx_rule_id` on `dialplan_rules`(`rule_id`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `dialplan_rules_includes` (
    `id`  INTEGER PRIMARY KEY AUTOINCREMENT,
    `rule_id` int(11),
    `priority` int(3),
    `include_rule_id` int(11)
);
CREATE INDEX IF NOT EXISTS `idx__dialplan_rules_includes__rule_id` on `dialplan_rules_includes`(`rule_id`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `gacl` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `role_type` int(1),
    `id_role` int(5),
    `id_entry_type` int(3),
    `id_entry` int(5),
    `type` int(1),
    `temp_mask` int(5),
    `r` int(1),
    `w` int(1),
    `d` int(1)
);
CREATE INDEX IF NOT EXISTS `idx_gacl__id_role` on `gacl`(`id_role`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `gacl_entry_types` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `entry_type` varchar(20)
);
CREATE INDEX IF NOT EXISTS `idx_gacl_entry_types__entry_type` on `gacl_entry_types`(`entry_type`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `ivr_tree` (
    `id`  INTEGER PRIMARY KEY AUTOINCREMENT,
    `parent_id` int(11),
    `command` varchar(200),
    `parameters` text,
    `number` varchar(20),
    `treeid` int(11)
);
CREATE INDEX IF NOT EXISTS `idx_ivr_tree_id` on `ivr_tree`(`id`);
CREATE INDEX IF NOT EXISTS `idx_ivr_tree_treeid` on `ivr_tree`(`treeid`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `outgoing_groups_main` (
    `id`  INTEGER PRIMARY KEY AUTOINCREMENT,
    `groupname` varchar(63) UNIQUE,
    `description` varchar(255) NOT NULL default ''
);
CREATE INDEX IF NOT EXISTS `idx_outgoing_groups_main_groupname` on `outgoing_groups_main`(`groupname`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `outgoing_groups_rules` (
    `id`  INTEGER PRIMARY KEY AUTOINCREMENT,
    `group_id` int(11),
    `priority` int(11),
    `trunkname` varchar(255),
    `prepend` varchar(15),
    `remove` varchar(15),
    `max_calls` int(11),
    `timeout` int(11),
    `rules_cnt` int(11)
);
CREATE INDEX IF NOT EXISTS `idx_outgoing_groups_rules_group_id` on `outgoing_groups_rules`(`group_id`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `paging` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `name` varchar(40) UNIQUE
);
CREATE INDEX IF NOT EXISTS `idx__paging_name` on `paging`(`name`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `paging_members` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `paging_id` int(11),
    `group_member` varchar(20)
);
CREATE INDEX IF NOT EXISTS `idx__paging_members_paging_id` on `paging_members`(`paging_id`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `pstn_trunks` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `username` varchar(20) UNIQUE,
    `technology` varchar(5),
    `ports` int(4),
    `settings_pbx` text,
    `settings_mgw` text
);
CREATE INDEX IF NOT EXISTS `idx_pstn_trunks_username` on `pstn_trunks`(`username`);
CREATE INDEX IF NOT EXISTS `idx_pstn_trunks_technology` on `pstn_trunks`(`technology`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `system` (
    `variable` varchar(20) PRIMARY KEY,
    `value` varchar(50)
);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `timetable_main` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `timetable` varchar(40) UNIQUE,
    `desc` text,
    `state` int(1)
);
CREATE INDEX IF NOT EXISTS `idx_timetable_main_timetable` on `timetable_main`(`timetable`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `timetable_additional` (
    `id`  INTEGER PRIMARY KEY AUTOINCREMENT,
    `parent_id` int(6),
    `day_of_week_from` int(1),
    `day_of_week_to` int(1),
    `day_id_from` int(2),
    `day_id_to` int(2),
    `month_id` int(2),
    `start_daytime` time,
    `end_daytime` time,
    `year_id` int(4),
    `enabled_id` tinyint(1)
);
CREATE INDEX IF NOT EXISTS `idx_timetable_additional_parent_id` on `timetable_additional`(`parent_id`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `trunks` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `username` varchar(20),
    `title` varchar(40) NOT NULL default '',
    `register` varchar(255),
    `settings_pbx` text,
    `settings_wms` text
);
CREATE INDEX IF NOT EXISTS `idx_trunks_username` on `trunks`(`username`);
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `wmsswitches` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `switchname` varchar(40),
    `description` text,
    `state` int(1),
    `swtype` int(1),
    `swnametype` varchar(41) UNIQUE
);
CREATE INDEX IF NOT EXISTS `idx_wmsswitches_switchname` on `wmsswitches`(`switchname`);
CREATE INDEX IF NOT EXISTS `idx_wmsswitches_swtype` on `wmsswitches`(`swtype`);
-- ------------------------------------
INSERT INTO `dialplan_rulenames`(`id`,`rulename`,`subrule_id`) VALUES('1','users','');
INSERT INTO `dialplan_rules_includes`(`id`,`rule_id`,`priority`,`include_rule_id`) VALUES('1','1','0','-4');
INSERT INTO `dialplan_rules`(`id`,`rule_id`,`number`,`exmatch`,`priority`,`application`,`parameters`,`dialplanappname`) VALUES('1','1','+XXXX.','','0','CorrectOutgoingNumber','"${EXTEN}","0","users"','app-correct-outgoing-number');
INSERT INTO `dialplan_rulenames`(`id`,`rulename`,`subrule_id`) VALUES('2','main','');
INSERT INTO `dialplan_rulenames`(`id`,`rulename`,`subrule_id`) VALUES('3','kite','');
INSERT INTO `dialplan_rulenames`(`id`,`rulename`,`subrule_id`) VALUES('4','classound','');
INSERT INTO `gacl_entry_types`(`id`, `entry_type`) VALUES (null,'users');
INSERT INTO `system`(`variable`,`value`) VALUES('version', '1.1');
INSERT INTO `system`(`variable`,`value`) VALUES('AUTOREG_STATUS', '0');
INSERT INTO `system`(`variable`,`value`) VALUES('PREFIX_EXTLINE', '0');
INSERT INTO `system`(`variable`,`value`) VALUES('QEVENTS', '0');
INSERT INTO `cac`(`cac_name`, `cac_networks`, `cac_limit`) VALUES('PBX', '', '0');
-- ------------------------------------
CREATE TABLE IF NOT EXISTS `rate` (
    `ratecard_id` INT NOT NULL,
    `dialprefix` VARCHAR(20) NOT NULL,
    `destination` VARCHAR(50) NOT NULL,
    `rate` FLOAT NOT NULL DEFAULT 0,
    `min_duration` INT NOT NULL,
    `billing_block` INT NOT NULL,
    `connect_charge` FLOAT NOT NULL DEFAULT 0,
    `start_day` INT(1) NOT NULL,
    `stop_day` INT(1) NOT NULL,
    `start_time` INT NOT NULL,
    `stop_time` INT NOT NULL
);
CREATE TABLE IF NOT EXISTS `ratecard` (
    `ratecard_id` INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
    `ratecard_name` VARCHAR(40) NOT NULL
);

CREATE INDEX IF NOT EXISTS `idx_rate_dialprefix` ON `rate` (`dialprefix`);
CREATE INDEX IF NOT EXISTS `idx_rate_ratecard_id` ON `rate` (`ratecard_id`);
CREATE INDEX IF NOT EXISTS `idx_ratecard_ratecard_id` ON `ratecard` (`ratecard_id`);
-- ------------------------------------
COMMIT;
