(function universalModuleDefinition(root, factory) {
    if (typeof exports === 'object'){
        // CommonJS
        module.exports = factory(require('jquery'));
    } else if (typeof define === 'function' && define.amd){
        // AMD
        define(['jquery'], factory);
    } else {
        // Browser
        root.RemoteSupport = factory(root.jQuery);
    }
}(this, function ($) {
    'use strict';

    function RemoteSupport(data) {
        this.constructor(data);
    }

    $.extend(RemoteSupport.prototype = {

        vtunServiceDoStartAjaxURL: 'api/v1/PBX/settings/remoteSupport',
        vtunPeriodicCheckStateAjaxURL: 'api/v1/PBX/settings/remoteSupport',

        constructor: function(data) {
            this.vtunInitServStat = data.vtunInitServStat;
            this._bindEvents();
            this._showVtunServiceValues(this.vtunInitServStat);
        },

        _showVtunServiceValues: function(status) {
            this.vtunInitServStat = status;
            ap_showWaitMessage('waitDiv', 0);
            var fontColor, fontMessage;

            if (status == '0') {
                fontColor = 'orange';
                fontMessage = WMS._t('state.ServerStarted');
                $('#vtun_service_reload').show();
                $('#vtun_service_stop').show();
                $('#vtun_service_start').hide();
            } else {
                fontColor = 'gray';
                fontMessage = WMS._t('state.ServerStopped');
                $('#vtun_service_reload').hide();
                $('#vtun_service_stop').hide();
                $('#vtun_service_start').show();
            }

            $('#vtun_service_status').html('<font color="' + fontColor + '">' + fontMessage + '</font>');
            $('#geo_location_post').removeAttr('disabled');
            $('#geo_location_post').attr('class', 'btn btn-primary');
            $('#geo_settings_save_btn').removeAttr('disabled');
            $('#geo_settings_save_btn').attr('class', 'btn btn-primary');
        },

        _bindEvents: function() {
            $('#vtun_service_reload').on('click', $.proxy(this._vtunServiceDoStart, this, 'restart'));
            $('#vtun_service_stop').on('click', $.proxy(this._vtunServiceDoStart, this, 'stop'));
            $('#vtun_service_start').on('click', $.proxy(this._vtunServiceDoStart, this, 'start'));
        },

        _vtunServiceDoStart: function(type) {
            this.checkCnt = 10;
            ap_showWaitMessage('waitDiv', 1);
            var errorFlag = false;

            var statusText = (type == 'restart') ? WMS._t('vtun.JS.Restarting') : WMS._t('vtun.JS.Starting');
            $('#vtun_status_block').text(statusText);

            if (type == undefined || type == '') {
                type = 'start';
            }

            $.ajax({
                url: this.vtunServiceDoStartAjaxURL,
                type: 'PUT',
                dataType: 'json',
                data: {
                    type: type
                },
                success: function(data, textStatus, transport) {
                    if (transport.status == 200 && transport.responseText != '') {
                        if (data.result.error != '') {
                            setError('error', data.result.error);
                            ap_showWaitMessage('waitDiv', 0);
                            $('#vtun_status_block').text(WMS._t('vtun.JS.ConnectionError'));
                            this._showVtunServiceValues('1');
                            errorFlag = true;
                        }
                    } else {
                        $('#vtun_status_block').text('HTTP transport problem.');
                        errorFlag = true;
                    }

                    if (!errorFlag) {
                        setTimeout(function() {
                            this._vtunPeriodicCheckState();
                        }.bind(this), 1500);
                    }
                }.bind(this),
                error: function(jqXHR, textStatus) {
                    console.error(textStatus);
                }
            });
        },
        _vtunPeriodicCheckState: function() {
            var started = false;
            $('#vtun_status_block').text(WMS._t('vtun.JS.Connecting'));

            $.ajax({
                type: 'POST',
                url: this.vtunPeriodicCheckStateAjaxURL,
                dataType: 'json',
                success: function(data, textStatus, transport) {
                    if (transport.status == 200 && transport.responseText != '') {
                        if (data.result.state == '0') {
                            $('#vtun_status_block').text('IP: ' + data.result.vtun_ip);
                            this._showVtunServiceValues(data.result.state);
                            started = true;
                            this.checkCnt = 0;
                        }
                    }

                    if (this.checkCnt > 0) {
                        this.checkCnt--;
                        setTimeout(function() {
                            this._vtunPeriodicCheckState();
                        }.bind(this), 3000);
                    } else {
                        if (!started) {
                            $('#vtun_status_block').text(WMS._t('vtun.JS.ConnectionTimeout'));
                            this._showVtunServiceValues('1');
                        }
                    }
                }.bind(this),
                error: function(jqXHR, textStatus) {
                    console.error(textStatus);
                }
            });
        }
    });

    return RemoteSupport;
}));
