export default class NetworkInterface {

    constructor(data) {
        this.activate = data.activate;
        this.address = data.address;
        this.addressInUse = data['address:inuse'];
        this.alias = data.alias;
        this.broadcast = data['broadcast:inuse'];
        this.enabled = data.enabled;
        this.gateway = data.gateway;
        this.interface = data.interface;
        this.kind = data.kind;
        this.link = data.link;
        this.netmask = data.netmask;
        this.netmaskInUse = data['netmask:inuse'];
        this.network = data.network;
        this.type = data.type;
        this.vlanRawDevice = data['vlan_raw_device'];
    }

    get interfaceAddr() {
        const addresses = [this.addressInUse];
        if (this.address && (this.address !== this.addressInUse)) {
            addresses.push(this.address);
        }

        return addresses.filter((item) => item).join('/');
    }

    get interfaceNetmask() {
        const masks = [this.netmaskInUse];
        if (this.address && (this.netmask !== this.netmaskInUse)) {
            masks.push(this.netmask);
        }

        return masks.filter((item) => item).join('/');
    }

    get isVlan() {
        return this.interface.includes('.');
    }

    get isVirtual() {
        return this.interface.includes(':');
    }

    get inactive() {
        return !this.addressInUse || !this.enabled;
    }

    get description() {
        const prefix = this.isVlan ? 'VLAN' : this.alias;
        return `${prefix} ${this.interface} ${this.type ? '(' + this.type + ')' : ''}`;
    }

}
