/* eslint-disable camelcase */
/* eslint-disable no-template-curly-in-string */

import translate from '@/modules/translate/translate';

export default class Phonebook {

    constructor(data) {
        this.id = data.id;
        this.name = data.name || '';
        this.contactsCnt = data.contacts_cnt || 0;
        this.syncInterval = data.sync_set === '1' ? `${data.sync_interval} ${translate('strings.hour')}` : '---';
        this.syncParams = data.sync_params ? JSON.parse(data.sync_params) : {
            ldap_map: {
                source_id: 'uid',
                username: 'cn',
                fax: 'facsimileTelephoneNumber',
                extension: 'telephoneNumber',
                office: 'wOfficePhone',
                email: 'mail',
                mobile: 'mobile'
            },
            activeD_map: {
                source_id: 'uid',
                username: 'cn',
                fax: 'facsimileTelephoneNumber',
                extension: 'telephoneNumber',
                office: 'wOfficePhone',
                email: 'mail',
                mobile: 'mobile'
            },
            domino_map: {
                source_id: 'uid',
                username: 'cn',
                fax: 'facsimileTelephoneNumber',
                extension: 'telephoneNumber',
                office: 'wOfficePhone',
                email: 'mail',
                mobile: 'mobile'
            },
            mysql_map: {
                source_id: 'id',
                username: 'name',
                office: 'phone',
                email: 'email',
                fax: 'fax',
                mobile: 'mobile',
                image_url: 'image_url'
            },
            hanaDb_map: {
                source_id: 'CardCode',
                username: 'CardName',
                office: 'Phone1',
                email: 'E_Mail',
                fax: 'Fax',
                mobile: 'Phone2',
                image_url: ''
            },
            mssql_map: {
                source_id: 'id',
                username: 'name',
                office: 'phone',
                email: 'email',
                fax: 'fax',
                mobile: 'mobile',
                image_url: 'image_url'
            },
            csv_map: {
                source_id: 'Id',
                shortcut: 'Shortcut',
                name_prefix: 'NamePrefix',
                username: 'Name',
                extension: 'Extension',
                office: 'Office',
                mobile: 'Mobile',
                home: 'Home',
                home_mobile: 'HomeMobile',
                phone: 'Phone',
                fax: 'Fax',
                email: 'Email',
                organization: 'Organization',
                user_class: 'Type',
                address: 'Address',
                vat_id: 'VatId',
                user_passport_type: 'DocumentType',
                user_passport_id: 'DocumentId',
                image_url: 'ImageUrl',
                note: 'Note'
            },
            office365_map: {
                source_id: 'id',
                name_prefix: 'nameTitle',
                username: 'name | company',
                office: 'phoneBusiness1',
                mobile: 'phoneMobile1',
                home: 'phoneHome1',
                home_mobile: 'phoneHome2',
                fax: 'phoneBusiness2',
                email: 'email1 | email2 | email3',
                organization: 'company',
                address: 'addressWork | addressHome | addressOther',
                note: 'notes',
                postal_code: 'postcodeHome | postcodeWork',
                city: 'cityHome | cityWork',
                province: 'regionHome | regionWork'
            },
            google_map: {
                source_id: 'id',
                name_prefix: 'namePrefix',
                username: 'name | organization',
                office: 'phoneWork',
                mobile: 'phoneMobile',
                home: 'phoneHome',
                home_mobile: 'phoneMain',
                fax: 'phoneWorkFax',
                email: 'emailWork | emailHome',
                organization: 'organization',
                address: 'addressWork | addressHome',
                note: 'notes',
                postal_code: 'postcodeHome | postcodeWork',
                city: 'cityHome | cityWork',
                province: 'regionHome | regionWork'
            },
            infusionsoft_map: {
                source_id: 'id',
                owner_id: 'owner',
                name_prefix: 'namePrefix',
                username: 'name | company',
                office: 'workPhone1 | workPhone2 | workPhone3 | workPhone4 | workPhone5',
                mobile: 'mobilePhone1 | mobilePhone2 | mobilePhone3 | mobilePhone4 | mobilePhone5',
                home: 'homePhone1 | homePhone2 | homePhone3 | homePhone4 | homePhone5',
                home_mobile: 'homePhone2 | homePhone3 | homePhone4 | homePhone5',
                phone: 'otherPhone1 | otherPhone2 | otherPhone3 | otherPhone4 | otherPhone5',
                fax: 'workFax1 | workFax2 | homeFax1 | homeFax2 | otherFax1 | otherFax2',
                email: 'email1 | email2 | email3',
                organization: 'company',
                user_class: 'contactType',
                address: 'billingStreetAddress1 | shippingStreetAddress1',
                note: 'notes',
                postal_code: 'billingPostalCode | shippingPostalCode',
                city: 'billingCity | shippingCity',
                province: 'billingState | shippingState'
            },
            exchange_map: {
                source_id: 'id',
                username: 'name | companyName',
                office: 'phoneCompanyMain | phoneAssistant | phoneBusiness | phoneBusiness2',
                mobile: 'phoneMobile | phoneCar',
                home: 'phoneHome',
                home_mobile: 'phoneHome2',
                phone: 'phonePrimary | phoneRadio | phoneOther',
                fax: 'phoneBusinessFax | phoneHomeFax | phoneOtherFax',
                email: 'email1 | email2 | email3',
                organization: 'companyName',
                address: 'addressBusiness | addressHome | addressOther',
                postal_code: 'addressBusinessPostalCode | addressHomePostalCode | addressOtherPostalCode',
                city: 'addressBusinessCity | addressHomeCity | addressOtherCity',
                province: 'addressBusinessState | addressHomeState | addressOtherState'
            },
            ldap_settings: {
                host: '',
                port: '389',
                secure: 'no',
                user: '',
                password: '',
                basedn: '',
                filter: '(&(objectCategory=person)(|(objectClass=user)(objectClass=contact))(!(userAccountControl:1.2.840.113556.1.4.803:=2)))'
            },
            activeD_settings: {
                host: '',
                port: '389',
                secure: 'no',
                user: '',
                password: '',
                basedn: '',
                filter: '(&(objectCategory=person)(|(objectClass=user)(objectClass=contact))(!(userAccountControl:1.2.840.113556.1.4.803:=2)))'
            },
            domino_settings: {
                host: '',
                port: '389',
                secure: 'no',
                user: '',
                password: '',
                basedn: '',
                filter: '(&(objectClass=dominoperson))'
            },
            mysql_settings: {
                host: '',
                port: '',
                user: '',
                password: '',
                database: '',
                timeout: '',
                filter: 'SELECT ${MAP} FROM `contacts_table` WHERE `type`=\'customer\''
            },
            mssql_settings: {
                host: '',
                port: '',
                user: '',
                password: '',
                database: '',
                timeout: '',
                filter: 'SELECT ${MAP} FROM [contacts_table] WHERE [type]=\'customer\''
            },
            hanaDb_settings: {
                host: '127.0.0.1',
                port: '30015',
                user: '',
                password: '',
                database: '',
                timeout: '0',
                filter: 'select ${MAP} from ${DBNAME}.\'OCRD\''
            },
            csv_settings: {
                import_type: 'upload',
                import_mountpoint: '',
                import_filepath: ''
            },
            office365_settings: {
                access_to_directory: '',
                mail: '',
                received_token_time: '',
                access_token: '',
                token_type: '',
                expires_in: '',
                id_token: '',
                id_token_expires_in: '',
                refresh_token: '',
                phonebooks: ''
            },
            google_settings: {
                mail: '',
                received_token_time: '',
                access_token: '',
                token_type: '',
                expires_in: '',
                refresh_token: '',
                phonebooks: ''
            },
            infusionsoft_settings: {
                mail: '',
                app: '',
                received_token_time: '',
                access_token: '',
                token_type: '',
                expires_in: '',
                refresh_token: ''
            },
            exchange_settings: {
                host: '',
                user: '',
                password: '',
                phonebooks: ''
            },
            recurrent_job: {
                enabled: 'no',
                interval: '2',
                email: ''
            },
            global: {
                backend: 'ldap',
                remove_users: 'no',
                erase_values: 'no'
            }
        };
    }

}
