function Network(core){
    this.client = core.client;
}

let networkUrl = '/v1/PBX/settings/network';

// TODO remove after Network API is implemented
function makeNetworkRequest(transport, {method, action, headers, data, qparams}) {
    return transport('/network/index.php', {
        method,
        headers,
        params: {
            class: 'classes/network/network.class.php',
            newclass: 'network',
            action,
            ...qparams
        },
        data
    })
        .then((response) => {
            if (response.data.errors) {
                return Promise.reject(response);
            }
            return response;
        });
}

function makeFormDataRequest(transport, action, settings) {
    const data = new FormData();
    data.set('newclass', 'network');
    data.set('action', action);
    data.set('settings', JSON.stringify({
        settings
    }));
    const headers = {
        'Content-Type': 'multipart/form-data'
    };
    return makeNetworkRequest(transport, {
        method: 'POST',
        headers,
        data
    })
        .then((response) => {
            if (response.data.errors) {
                return Promise.reject(response);
            }
            return response;
        });
}

Object.assign(Network.prototype, {
    namespace: 'PBX.Settings.Network',
    getInterfaces(){
        return this.client.send('GET', networkUrl + '/interfaces');
    },
    getInterfacesOld() {
        return makeNetworkRequest(this.client._transport, {
            method: 'GET',
            action: 'getInterfaces'
        });
    },
    getHosts() {
        return makeNetworkRequest(this.client._transport, {
            method: 'GET',
            action: 'getHosts'
        });
    },
    getRoutes() {
        return makeNetworkRequest(this.client._transport, {
            method: 'GET',
            action: 'getRoutes'
        });
    },
    getDns() {
        return makeNetworkRequest(this.client._transport, {
            method: 'GET',
            action: 'getRoutes'
        });
    },
    getNetworkSettings() {
        return makeNetworkRequest(this.client._transport, {
            method: 'GET',
            action: 'getNetworkSettings'
        });
    },
    updateInterface(settings) {
        return makeFormDataRequest(this.client._transport, 'setInterface', settings);
    },
    updateRoute(settings) {
        return makeFormDataRequest(this.client._transport, 'setRoute', settings);
    },
    updateHost(settings) {
        return makeFormDataRequest(this.client._transport, 'setHost', settings);
    },
    updateNetworkSettings(settings) {
        return makeFormDataRequest(this.client._transport, 'restartNetwork', settings);
    },
    updateDnsSettings(settings) {
        return makeFormDataRequest(this.client._transport, 'restartDns', settings);
    },
    deleteInterfaces(interfaces) {
        return makeNetworkRequest(this.client._transport, {
            method: 'GET',
            action: 'delInterfaces',
            qparams: {
                interfaces
            }
        });
    },
    deleteRoutes(routes) {
        return makeNetworkRequest(this.client._transport, {
            method: 'GET',
            action: 'delRoutes',
            qparams: {
                routes
            }
        });
    },
    deleteHosts(addresses) {
        return makeNetworkRequest(this.client._transport, {
            method: 'GET',
            action: 'delHosts',
            qparams: {
                addresses
            }
        });
    },
    updateMasquerading() {
        return makeFormDataRequest(this.client._transport, 'updateMasquarding');
    },
    updateBridge() {
        return makeFormDataRequest(this.client._transport, 'updateBridge');
    }
});

export default Network;
