const SIZES = ['B', 'Kb', 'Mb', 'Gb', 'Tb'];

export const FILE_SIZE = (data) => {
    let size = '0 B';
    data = Number(data);

    if (data) {
        let i = 0;
        while (data > 1024) {
            data /= 1024;
            i++;
        }
        size = `${Math.ceil(data * 100) / 100} ${SIZES[i]}`;
    }

    return size;
};

/* @see https://stackoverflow.com/questions/4068373/center-a-popup-window-on-screen */
export const popupCenter = ({url, title, w, h}) => {
    // Fixes dual-screen position                             Most browsers      Firefox
    const dualScreenLeft = window.screenLeft !== undefined ? window.screenLeft : window.screenX;
    const dualScreenTop = window.screenTop !== undefined ? window.screenTop : window.screenY;

    const width = window.innerWidth ? window.innerWidth : document.documentElement.clientWidth ? document.documentElement.clientWidth : screen.width;
    const height = window.innerHeight ? window.innerHeight : document.documentElement.clientHeight ? document.documentElement.clientHeight : screen.height;

    const systemZoom = width / window.screen.availWidth;
    const left = (width - w) / 2 / systemZoom + dualScreenLeft;
    const top = (height - h) / 2 / systemZoom + dualScreenTop;
    const newWindow = window.open(url, title,
        `
      scrollbars=yes,
      width=${w / systemZoom},
      height=${h / systemZoom},
      top=${top},
      left=${left}
        `
    );

    if (window.focus) {
        newWindow.focus();
    }
};

export const downloadFileFromApi = (data, name) => {
    const url = window.URL.createObjectURL(new Blob([data]));
    const link = document.createElement('a');
    link.href = url;
    link.setAttribute('download', name);
    document.body.appendChild(link);
    link.click();
};

export const capitalize = string => {
    return `${string.charAt(0).toUpperCase()}${string.slice(1).toLowerCase()}`;
};

export function mergeDeep(target, ...sources) {
    if (!sources.length) return target;
    const source = sources.shift();

    const isObject = item => item && typeof item === 'object' && !Array.isArray(item);
    if (isObject(target) && isObject(source)) {
        for (const key in source) {
            if (isObject(source[key])) {
                if (!target[key]) Object.assign(target, {[key]: {}});
                mergeDeep(target[key], source[key]);
            } else {
                Object.assign(target, {[key]: source[key]});
            }
        }
    }

    return mergeDeep(target, ...sources);
}
