import translate from '../modules/translate/translate';
import {mergeDeep} from './helpers';

export const fileName = str => Boolean(str.match(/^[0-9a-zA-Z-._]*$/, 'g'));

export const ipAddress = str => /^((25[0-5]|(2[0-4]|1\d|[1-9]|)\d)\.?\b){4}$/.test(str);

export const port = str => /^([1-9][0-9]{0,3}|[1-5][0-9]{4}|6[0-4][0-9]{3}|65[0-4][0-9]{2}|655[0-2][0-9]|6553[0-5])$/.test(str);

export const showErrorFormat = data => {
    if (!Array.isArray(data)) {
        data = [data];
    }

    data = data.filter(item => Object.keys(item).length !== 0);

    let errors = {};

    data.forEach(item => {
        let reference = {};
        const accumulator = reference;
        const props = item.fieldName.split('.');
        const last = props.pop();

        props.forEach(prop => {
            reference[prop] = {};
            reference = reference[prop];
        });

        reference[last] = {
            code: 'Invalid',
            reason: item.reason
        };

        errors = mergeDeep(errors, accumulator);
    });

    return {
        data: {
            reason: 'Validation error',
            errors
        }
    };
};

export const ERRORS_TEXT = {
    required: translate('rules.CannotBeEmpty'),
    fileName: translate('rules.enterValidValue'),
    numeric: translate('rules.enterValidValue'),
    integer: translate('rules.enterValidValue'),
    ipAddress: translate('rules.enterValidValue') + ' IP',
    betweenWeight: translate('rules.enterValidValue') + ' (0-50)',
    minValueRetry: translate('rules.enterValidValue') + ' (min: 1)',
    minValueZero: translate('rules.enterValidValue') + '(min: 0)',
    traceFileName: translate('rules.enterValidValue') + ' [0-9a-zA-Z.-_]',
    betweenInterDigitTimeout: translate('rules.enterValidValue') + ' (1-12)',
    betweenParkTimeout: translate('rules.enterValidValue') + ' (0-32767)',
    betweenIntDialTimeout: translate('rules.enterValidValue') + ' (10-600)'
};
