import Vue from 'vue';
import router from './router/index';
import {ResetArrayMethods, ResetObjectMethods} from '@/modules/reset-methods';
import App from './App.vue';
import store from '@/store';
import WmsLoader from '@/components/wms-loader';
import WmsTranslation from '@/modules/translate/index';
import ApiPlugin from '@/modules/wms-api';
import Vuelidate from 'vuelidate';
// import {BFormGroup, BForm, BFormRadio, BFormSelect, BTab } from 'bootstrap-vue';

import 'bootstrap-vue/dist/bootstrap-vue.css';
import 'element-ui/lib/theme-chalk/date-picker.css';
import 'element-ui/lib/theme-chalk/select.css';
import 'element-ui/lib/theme-chalk/transfer.css';
import './assets/css/index.scss';

// eslint-disable-next-line no-unused-vars
import '@/modules/security/acl';
import config from '@/configuration/config';
import Modal from './components/modal/index.js';
import Toast from './modules/toast.js';
import {ROOT_ID} from '@/configuration/constants';
// import {BForm} from 'bootstrap-vue/src/components/form';
// import {BFormGroup} from 'bootstrap-vue/src/components/form-group';

import {BootstrapVue} from 'bootstrap-vue';

// reset methods after use prototype.js
ResetArrayMethods(['map', 'filter', 'each', 'toJSON']);
ResetObjectMethods(['keys']);
window.resetedMapMethod = Array.prototype.map;
window.resetedFilterMethod = Array.prototype.filter;
window.resetedKeysMethod = Object.keys;
window.resetedEachMethod = Array.prototype.each;
window.resetedToJSONMethod = Array.prototype.toJSON;

Vue.use(WmsTranslation);
Vue.use(ApiPlugin);
Vue.use(Modal);
Vue.use(Toast);
Vue.use(Vuelidate);
Vue.use(BootstrapVue);

window.wmsApp = new Vue({
    el: ROOT_ID,
    router,
    store,
    render: h => h(App),
    config: {
        devtools: config.devtool
    },
    mounted() {
        WmsLoader.hide();
        this.$store.watch(this.$store.getters.getLoader, n => {
            if (n > 0) {
                WmsLoader.show();
            } else {
                WmsLoader.hide();
            }
        });
    }
});
