const storage = localStorage ?? {};
if (!storage.jStorage) {
    storage.jStorage = '{}';
}

const CLEAR = () => {
    storage.jStorage = '{}';
};
const SET_STORAGE = (key, value) => {
    const data = JSON.parse(storage.jStorage);
    data[key] = value;
    storage.jStorage = JSON.stringify(data);
};

export default {
    namespaced: true,
    state: {
        hideSidebar: false,
        dialplanTab: 0,
        trunkTab: 0,
        devicesTab: 0,
        usersTab: 0,
        pbxDn: '*',
        excludedUsersTableColumns: [],
        excludedDevicesTableColumns: []
    },
    getters: {
        isHideSidebar: ({hideSidebar}) => hideSidebar,
        selectedDialplansTab: ({dialplanTab}) => dialplanTab ?? 0,
        selectedTrunksTab: ({trunkTab}) => trunkTab ?? 0,
        selectedDevicesTab: ({devicesTab}) => devicesTab ?? 0,
        selectedUsersTab: ({usersTab}) => usersTab ?? 0,
        selectedPbx: ({pbxDn}) => pbxDn ?? null,
        selectedHotelsTab: ({hotelsTab}) => hotelsTab ?? 0,
        excludedUsersTableColumns: ({excludedUsersTableColumns}) => excludedUsersTableColumns,
        excludedDevicesTableColumns: ({excludedDevicesTableColumns}) => excludedDevicesTableColumns
    },
    actions: {
        init({commit}) {
            commit('init', JSON.parse(storage.jStorage));
        },
        toggleSidebar({commit, getters}) {
            commit('set', {key: 'hideSidebar', value: !getters.isHideSidebar});
        },
        setStorage({commit}, {key, value}) {
            commit('set', {key, value});
        },
        logout() {
            CLEAR();
        }
    },
    mutations: {
        init(state, data) {
            Object.assign(state, data);
        },
        set(state, {key, value}) {
            state[key] = value;
            SET_STORAGE(key, value);
        }
    }
};
